@@ -1,12 +1,14 @@
 use super::*;
 
 mod abi;
+mod compose;
 mod interface;
 mod into_param;
 mod runtime_name;
 mod runtime_type;
 
 pub use abi::*;
+pub use compose::*;
 pub use interface::*;
 pub use into_param::*;
 pub use runtime_name::*;
